From 912253371d58a27427719d50aa5cf140153f78df Mon Sep 17 00:00:00 2001
From: Adrian Holovaty <adrian@holovaty.com>
Date: Mon, 18 Jul 2005 17:23:04 +0000
Subject: [PATCH] Moved django.views.decorators.cache.compress_string into
 django.utils.text

git-svn-id: http://code.djangoproject.com/svn/django/trunk@175 bcc190cf-cafb-0310-a4f2-bffc1f526a37
---
 django/utils/text.py             | 10 ++++++++++
 django/views/decorators/cache.py | 14 +++-----------
 2 files changed, 13 insertions(+), 11 deletions(-)

diff --git a/django/utils/text.py b/django/utils/text.py
index cb9e9454d7..a0d106bb31 100644
--- a/django/utils/text.py
+++ b/django/utils/text.py
@@ -106,3 +106,13 @@ def phone2numeric(phone):
          's': '7', 'r': '7', 'u': '8', 't': '8', 'w': '9', 'v': '8',
          'y': '9', 'x': '9'}.get(m.group(0).lower())
     return letters.sub(char2number, phone)
+
+# From http://www.xhaus.com/alan/python/httpcomp.html#gzip
+# Used with permission.
+def compress_string(s):
+    import cStringIO, gzip
+    zbuf = cStringIO.StringIO()
+    zfile = gzip.GzipFile(mode='wb', compresslevel=6, fileobj=zbuf)
+    zfile.write(s)
+    zfile.close()
+    return zbuf.getvalue()
diff --git a/django/views/decorators/cache.py b/django/views/decorators/cache.py
index 52501f74d5..7c76ef272d 100644
--- a/django/views/decorators/cache.py
+++ b/django/views/decorators/cache.py
@@ -1,15 +1,7 @@
 from django.core.cache import cache
 from django.utils.httpwrappers import HttpResponseNotModified
-import cStringIO, datetime, gzip, md5
-
-# From http://www.xhaus.com/alan/python/httpcomp.html#gzip
-# Used with permission.
-def compress_string(s):
-    zbuf = cStringIO.StringIO()
-    zfile = gzip.GzipFile(mode='wb', compresslevel=6, fileobj=zbuf)
-    zfile.write(s)
-    zfile.close()
-    return zbuf.getvalue()
+from django.utils.text import compress_string
+import datetime, md5
 
 def cache_page(view_func, cache_timeout, key_prefix=''):
     """
@@ -21,7 +13,7 @@ def cache_page(view_func, cache_timeout, key_prefix=''):
     variable. Use key_prefix if your Django setup has multiple sites that
     use cache; otherwise the cache for one site would affect the other. A good
     example of key_prefix is to use sites.get_current().domain, because that's
     unique across all CMS instances on a particular server.
     """
     def _check_cache(request, *args, **kwargs):
         try:
@@ -21,7 +13,7 @@ def cache_page(view_func, cache_timeout, key_prefix=''):
     use cache; otherwise the cache for one site would affect the other. A good
     example of key_prefix is to use sites.get_current().domain, because that's
-    unique across all CMS instances on a particular server.
+    unique across all Django instances on a particular server.
     """
     def _check_cache(request, *args, **kwargs):